# seaborn.husl_palette

```py
seaborn.husl_palette(n_colors=6, h=0.01, s=0.9, l=0.65)
```

Get a set of evenly spaced colors in HUSL hue space.

h, s, and l should be between 0 and 1

| Parameters: | **n_colors** : int

> number of colors in the palette

**h** : float

> first hue

**s** : float

> saturation

**l** : float

> lightness

 |
| --- | --- |
| Returns: | **palette** : seaborn color palette

> List-like object of colors as RGB tuples.

 |
| --- | --- |

See also

Make a palette using evently spaced circular hues in the HSL system.

Examples

Create a palette of 10 colors with the default parameters:

```py
>>> import seaborn as sns; sns.set()
>>> sns.palplot(sns.husl_palette(10))

```

![http://seaborn.pydata.org/_images/seaborn-husl_palette-1.png](img/6c7a1ce9ff5aa3607ad3bf275bd012fc.jpg)

Create a palette of 10 colors that begins at a different hue value:

```py
>>> sns.palplot(sns.husl_palette(10, h=.5))

```

![http://seaborn.pydata.org/_images/seaborn-husl_palette-2.png](img/e576eaf00adad68b231a4c2b8845d6e0.jpg)

Create a palette of 10 colors that are darker than the default:

```py
>>> sns.palplot(sns.husl_palette(10, l=.4))

```

![http://seaborn.pydata.org/_images/seaborn-husl_palette-3.png](img/752dc56ea71ef769a622efe0d5ea1b56.jpg)

Create a palette of 10 colors that are less saturated than the default:

```py
>>> sns.palplot(sns.husl_palette(10, s=.4))

```

![http://seaborn.pydata.org/_images/seaborn-husl_palette-4.png](img/47c55edddae366e8d447c323d69b197f.jpg)