# seaborn.hls_palette

```py
seaborn.hls_palette(n_colors=6, h=0.01, l=0.6, s=0.65)
```

Get a set of evenly spaced colors in HLS hue space.

h, l, and s should be between 0 and 1

| Parameters: | **n_colors** : int

> number of colors in the palette

**h** : float

> first hue

**l** : float

> lightness

**s** : float

> saturation

 |
| --- | --- |
| Returns: | **palette** : seaborn color palette

> List-like object of colors as RGB tuples.

 |
| --- | --- |

See also

Make a palette using evently spaced circular hues in the HUSL system.

Examples

Create a palette of 10 colors with the default parameters:

```py
>>> import seaborn as sns; sns.set()
>>> sns.palplot(sns.hls_palette(10))

```

![http://seaborn.pydata.org/_images/seaborn-hls_palette-1.png](img/5147a9e7a6cd2453c2e80dd967724f7e.jpg)

Create a palette of 10 colors that begins at a different hue value:

```py
>>> sns.palplot(sns.hls_palette(10, h=.5))

```

![http://seaborn.pydata.org/_images/seaborn-hls_palette-2.png](img/077b00661754439549e60127485a6a4a.jpg)

Create a palette of 10 colors that are darker than the default:

```py
>>> sns.palplot(sns.hls_palette(10, l=.4))

```

![http://seaborn.pydata.org/_images/seaborn-hls_palette-3.png](img/fdcac2831e87bea8b0a208095eb15adc.jpg)

Create a palette of 10 colors that are less saturated than the default:

```py
>>> sns.palplot(sns.hls_palette(10, s=.4))

```

![http://seaborn.pydata.org/_images/seaborn-hls_palette-4.png](img/98715db5f9ee15781a7c49624ec8dafc.jpg)