# seaborn.dark_palette

```py
seaborn.dark_palette(color, n_colors=6, reverse=False, as_cmap=False, input='rgb')
```

Make a sequential palette that blends from dark to `color`.

This kind of palette is good for data that range between relatively uninteresting low values and interesting high values.

The `color` parameter can be specified in a number of ways, including all options for defining a color in matplotlib and several additional color spaces that are handled by seaborn. You can also use the database of named colors from the XKCD color survey.

If you are using the IPython notebook, you can also choose this palette interactively with the [`choose_dark_palette()`](seaborn.choose_dark_palette.html#seaborn.choose_dark_palette "seaborn.choose_dark_palette") function.

| Parameters: | **color** : base color for high values

> hex, rgb-tuple, or html color name

**n_colors** : int, optional

> number of colors in the palette

**reverse** : bool, optional

> if True, reverse the direction of the blend

**as_cmap** : bool, optional

> if True, return as a matplotlib colormap instead of list

**input** : {‘rgb’, ‘hls’, ‘husl’, xkcd’}

> Color space to interpret the input color. The first three options apply to tuple inputs and the latter applies to string inputs.

 |
| --- | --- |
| Returns: | **palette or cmap** : seaborn color palette or matplotlib colormap

> List-like object of colors as RGB tuples, or colormap object that can map continuous values to colors, depending on the value of the `as_cmap` parameter.

 |
| --- | --- |

See also

Create a sequential palette with bright low values.Create a diverging palette with two colors.

Examples

Generate a palette from an HTML color:

```py
>>> import seaborn as sns; sns.set()
>>> sns.palplot(sns.dark_palette("purple"))

```

![http://seaborn.pydata.org/_images/seaborn-dark_palette-1.png](img/d206a78223b0280bfffbfd7cdb262145.jpg)

Generate a palette that decreases in lightness:

```py
>>> sns.palplot(sns.dark_palette("seagreen", reverse=True))

```

![http://seaborn.pydata.org/_images/seaborn-dark_palette-2.png](img/eac4541fd6a3e7b30eb535e0a1aab99f.jpg)

Generate a palette from an HUSL-space seed:

```py
>>> sns.palplot(sns.dark_palette((260, 75, 60), input="husl"))

```

![http://seaborn.pydata.org/_images/seaborn-dark_palette-3.png](img/6e81b4c302189f59de63f96dbee3a197.jpg)

Generate a colormap object:

```py
>>> from numpy import arange
>>> x = arange(25).reshape(5, 5)
>>> cmap = sns.dark_palette("#2ecc71", as_cmap=True)
>>> ax = sns.heatmap(x, cmap=cmap)

```

![http://seaborn.pydata.org/_images/seaborn-dark_palette-4.png](img/f153ef2783202a95337d9ea723fe2984.jpg)