# seaborn.diverging_palette

```py
seaborn.diverging_palette(h_neg, h_pos, s=75, l=50, sep=10, n=6, center='light', as_cmap=False)
```

Make a diverging palette between two HUSL colors.

If you are using the IPython notebook, you can also choose this palette interactively with the [`choose_diverging_palette()`](seaborn.choose_diverging_palette.html#seaborn.choose_diverging_palette "seaborn.choose_diverging_palette") function.

| Parameters: | **h_neg, h_pos** : float in [0, 359]

> Anchor hues for negative and positive extents of the map.

**s** : float in [0, 100], optional

> Anchor saturation for both extents of the map.

**l** : float in [0, 100], optional

> Anchor lightness for both extents of the map.

**n** : int, optional

> Number of colors in the palette (if not returning a cmap)

**center** : {“light”, “dark”}, optional

> Whether the center of the palette is light or dark

**as_cmap** : bool, optional

> If true, return a matplotlib colormap object rather than a list of colors.

 |
| --- | --- |
| Returns: | **palette or cmap** : seaborn color palette or matplotlib colormap

> List-like object of colors as RGB tuples, or colormap object that can map continuous values to colors, depending on the value of the `as_cmap` parameter.

 |
| --- | --- |

See also

Create a sequential palette with dark values.Create a sequential palette with light values.

Examples

Generate a blue-white-red palette:

```py
>>> import seaborn as sns; sns.set()
>>> sns.palplot(sns.diverging_palette(240, 10, n=9))

```

![http://seaborn.pydata.org/_images/seaborn-diverging_palette-1.png](img/35c6cb5f121884b387bc70e68ed2a22d.jpg)

Generate a brighter green-white-purple palette:

```py
>>> sns.palplot(sns.diverging_palette(150, 275, s=80, l=55, n=9))

```

![http://seaborn.pydata.org/_images/seaborn-diverging_palette-2.png](img/bc461a32c1b91013ce1dbb7e3a78d94c.jpg)

Generate a blue-black-red palette:

```py
>>> sns.palplot(sns.diverging_palette(250, 15, s=75, l=40,
...                                   n=9, center="dark"))

```

![http://seaborn.pydata.org/_images/seaborn-diverging_palette-3.png](img/9003952e6b318f40954e978ce39dd033.jpg)

Generate a colormap object:

```py
>>> from numpy import arange
>>> x = arange(25).reshape(5, 5)
>>> cmap = sns.diverging_palette(220, 20, sep=20, as_cmap=True)
>>> ax = sns.heatmap(x, cmap=cmap)

```

![http://seaborn.pydata.org/_images/seaborn-diverging_palette-4.png](img/f0eb41dc444960d4e07f9de19e5e8568.jpg)