# seaborn.mpl_palette

```py
seaborn.mpl_palette(name, n_colors=6)
```

Return discrete colors from a matplotlib palette.

Note that this handles the qualitative colorbrewer palettes properly, although if you ask for more colors than a particular qualitative palette can provide you will get fewer than you are expecting. In contrast, asking for qualitative color brewer palettes using [`color_palette()`](seaborn.color_palette.html#seaborn.color_palette "seaborn.color_palette") will return the expected number of colors, but they will cycle.

If you are using the IPython notebook, you can also use the function [`choose_colorbrewer_palette()`](seaborn.choose_colorbrewer_palette.html#seaborn.choose_colorbrewer_palette "seaborn.choose_colorbrewer_palette") to interactively select palettes.

| Parameters: | **name** : string

> Name of the palette. This should be a named matplotlib colormap.

**n_colors** : int

> Number of discrete colors in the palette.

 |
| --- | --- |
| Returns: | **palette or cmap** : seaborn color palette or matplotlib colormap

> List-like object of colors as RGB tuples, or colormap object that can map continuous values to colors, depending on the value of the `as_cmap` parameter.

 |
| --- | --- |

Examples

Create a qualitative colorbrewer palette with 8 colors:

```py
>>> import seaborn as sns; sns.set()
>>> sns.palplot(sns.mpl_palette("Set2", 8))

```

![http://seaborn.pydata.org/_images/seaborn-mpl_palette-1.png](img/df633411e4b51b4749de8c5349b438cc.jpg)

Create a sequential colorbrewer palette:

```py
>>> sns.palplot(sns.mpl_palette("Blues"))

```

![http://seaborn.pydata.org/_images/seaborn-mpl_palette-2.png](img/e369a8cb7348d971f2471d297addf456.jpg)

Create a diverging palette:

```py
>>> sns.palplot(sns.mpl_palette("seismic", 8))

```

![http://seaborn.pydata.org/_images/seaborn-mpl_palette-3.png](img/2690d286a343ff53a43d15d54fc86e91.jpg)

Create a “dark” sequential palette:

```py
>>> sns.palplot(sns.mpl_palette("GnBu_d"))

```

![http://seaborn.pydata.org/_images/seaborn-mpl_palette-4.png](img/dc21c66a962fb741f9f8f63c0374fae1.jpg)